@@ -29,12 +29,12 @@ from .models import ICMPRequest, ICMPReply, Host, Hop
 from .ping import ping, multiping
 from .traceroute import traceroute
 from .exceptions import *
-from .utils import PID, is_ipv6_address
+from .utils import PID, is_ipv4_address, is_ipv6_address
 
 
 __author__    = 'Valentin BELYN'
 __copyright__ = 'Copyright 2017-2020 Valentin BELYN'
 __license__   = 'GNU Lesser General Public License v3.0'
 
-__version__   = '1.1.3'
-__build__     = '200903'
+__version__   = '1.2.2'
+__build__     = '201010'
